@@ -10,6 +10,8 @@ dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python-feedp
 
 # update demotions
 (cd utils && ./demotions.py utopic vivid > demoted.cfg)
+# update demotions
+(cd utils && ./demotions.py trusty vivid > demoted.cfg.trusty)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 #(cd utils && ./demotions.py trusty w00t > demoted.cfg.trusty)
 
@@ -44,5 +46,5 @@ nosetests3
 rm -f ./tests/data-sources-list-test/apt.log
 
 # update version
-DEBVER=$(LC_ALL=C dpkg-parsechangelog |sed -n -e '/^Version:/s/^Version: //p' | sed s/.*://)
+DEBVER=$(LC_ALL=C dpkg-parsechangelog |sed -n -e '/^Version:/s/^Version: //p' | sed 's/.*://')
 echo "VERSION = '$DEBVER'" > DistUpgrade/DistUpgradeVersion.py
